[Scummvm-cvs-logs] scummvm master -> 52059bf95cc10cc2ad037828f8c734e643198c86

Strangerke Strangerke at scummvm.org
Thu Aug 22 23:38:51 CEST 2013


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
52059bf95c TSAGE: Replace some British English by American English


Commit: 52059bf95cc10cc2ad037828f8c734e643198c86
    https://github.com/scummvm/scummvm/commit/52059bf95cc10cc2ad037828f8c734e643198c86
Author: Strangerke (strangerke at scummvm.org)
Date: 2013-08-22T14:37:55-07:00

Commit Message:
TSAGE: Replace some British English by American English

Changed paths:
    engines/tsage/blue_force/blueforce_scenes1.cpp
    engines/tsage/blue_force/blueforce_scenes5.cpp
    engines/tsage/blue_force/blueforce_scenes5.h
    engines/tsage/converse.cpp
    engines/tsage/core.cpp
    engines/tsage/globals.cpp
    engines/tsage/globals.h
    engines/tsage/graphics.cpp
    engines/tsage/ringworld2/ringworld2_logic.cpp
    engines/tsage/ringworld2/ringworld2_scenes0.cpp
    engines/tsage/ringworld2/ringworld2_scenes1.cpp
    engines/tsage/ringworld2/ringworld2_speakers.cpp
    engines/tsage/ringworld2/ringworld2_speakers.h



diff --git a/engines/tsage/blue_force/blueforce_scenes1.cpp b/engines/tsage/blue_force/blueforce_scenes1.cpp
index 9f1e9ce..32d8758 100644
--- a/engines/tsage/blue_force/blueforce_scenes1.cpp
+++ b/engines/tsage/blue_force/blueforce_scenes1.cpp
@@ -3237,7 +3237,7 @@ void Scene190::postInit(SceneObjectList *OwnerList) {
 	BF_GLOBALS._player.postInit();
 	BF_GLOBALS._player.disableControl();
 
-	// Initialise objects
+	// Initialize objects
 	_door.postInit();
 	_door.setVisage(190);
 	_door.setStrip(1);
diff --git a/engines/tsage/blue_force/blueforce_scenes5.cpp b/engines/tsage/blue_force/blueforce_scenes5.cpp
index abadc43..25accbb 100644
--- a/engines/tsage/blue_force/blueforce_scenes5.cpp
+++ b/engines/tsage/blue_force/blueforce_scenes5.cpp
@@ -1459,7 +1459,7 @@ void Scene560::postInit(SceneObjectList *OwnerList) {
 	_lamp.setDetails(Rect(197, 43, 214, 56), 560, 7, 19, 30, 1, NULL);
 	_item4.setDetails(Rect(121, 18, 156, 54), 560, 8, 20, 31, 1, NULL);
 	_trophy.setDetails(Rect(259, 52, 275, 63), 560, 10, 22, 33, 1, NULL);
-	_watercolours.setDetails(Rect(214, 48, 239, 64), 560, 12, 24, 35, 1, NULL);
+	_waterColors.setDetails(Rect(214, 48, 239, 64), 560, 12, 24, 35, 1, NULL);
 	_fileCabinets.setDetails(Rect(0, 47, 49, 100), 560, 14, 26, 37, 1, NULL);
 	_certificate.setDetails(Rect(280, 51, 292, 62), 560, 11, 23, 34, 1, NULL);
 	_bookcase.setDetails(Rect(176, 0, 319, 103), 560, 9, 21, 32, 1, NULL);
diff --git a/engines/tsage/blue_force/blueforce_scenes5.h b/engines/tsage/blue_force/blueforce_scenes5.h
index 73d323f..56bf20c 100644
--- a/engines/tsage/blue_force/blueforce_scenes5.h
+++ b/engines/tsage/blue_force/blueforce_scenes5.h
@@ -225,7 +225,7 @@ public:
 	NamedObject _object6;
 	PicturePart _picture1, _picture2, _picture3, _picture4;
 	Computer _computer;
-	NamedHotspot _chair, _lamp, _item4, _trophy, _watercolours, _fileCabinets;
+	NamedHotspot _chair, _lamp, _item4, _trophy, _waterColors, _fileCabinets;
 	NamedHotspot _certificate, _bookcase, _desk, _carpet, _item12, _office;
 	ASound _sound1;
 	bool _field380;
diff --git a/engines/tsage/converse.cpp b/engines/tsage/converse.cpp
index 8ae6a0d..9828ca7 100644
--- a/engines/tsage/converse.cpp
+++ b/engines/tsage/converse.cpp
@@ -707,7 +707,7 @@ void StripManager::synchronize(Serializer &s) {
 	for (int i = 0; i < arrSize; ++i)
 		_obj44List[i].synchronize(s);
 
-	// Synhcronise script data
+	// Synchronize script data
 	int scriptSize = _script.size();
 	s.syncAsUint16LE(scriptSize);
 	if (s.isLoading())
@@ -858,7 +858,7 @@ void StripManager::signal() {
 						++obj44Idx;
 
 					if (_obj44List[obj44Idx]._field16[0]) {
-						// WORKAROUND: The _lookupList isn't always correctly initialised. But it always
+						// WORKAROUND: The _lookupList isn't always correctly initialized. But it always
 						// seems to be set to the R2_GLOBALS._stripManager_lookupList, so manually set it
 						if (!_lookupList)
 							_lookupList = R2_GLOBALS._stripManager_lookupList;
diff --git a/engines/tsage/core.cpp b/engines/tsage/core.cpp
index b632aa8..0080226 100644
--- a/engines/tsage/core.cpp
+++ b/engines/tsage/core.cpp
@@ -3997,7 +3997,7 @@ int WalkRegions::indexOf(const Common::Point &pt, const Common::List<int> *index
 }
 
 void WalkRegions::synchronize(Serializer &s) {
-	// Synchronise the list of disabled regions as a list of values terminated with a '-1'
+	// Synchronize the list of disabled regions as a list of values terminated with a '-1'
 	int regionId = 0;
 	if (s.isLoading()) {
 		_disabledRegions.clear();
diff --git a/engines/tsage/globals.cpp b/engines/tsage/globals.cpp
index 6d1f4ce..f7ee76a 100644
--- a/engines/tsage/globals.cpp
+++ b/engines/tsage/globals.cpp
@@ -483,7 +483,7 @@ void Ringworld2Globals::reset() {
 	Common::fill(&_scannerFrequencies[0], &_scannerFrequencies[MAX_CHARACTERS], 1);
 	_speechSubtitles = SPEECH_VOICE | SPEECH_TEXT;
 	_insetUp = 0;
-	_frameEdgeColour = 2;
+	_frameEdgeColor = 2;
 	Common::fill(&_stripManager_lookupList[0], &_stripManager_lookupList[12], 0);
 	_stripManager_lookupList[0] = 1;
 	_stripManager_lookupList[1] = 1;
@@ -566,7 +566,7 @@ void Ringworld2Globals::synchronize(Serializer &s) {
 		s.syncAsByte(_stripManager_lookupList[i]);
 
 	s.syncAsSint16LE(_insetUp);
-	s.syncAsByte(_frameEdgeColour);
+	s.syncAsByte(_frameEdgeColor);
 }
 
 } // end of namespace Ringworld2
diff --git a/engines/tsage/globals.h b/engines/tsage/globals.h
index e91a74b..8de5f7f 100644
--- a/engines/tsage/globals.h
+++ b/engines/tsage/globals.h
@@ -258,7 +258,7 @@ public:
 	byte _fadePaletteMap[10][256];
 	byte _paletteMap[4096];
 	int _insetUp;
-	int _frameEdgeColour;	// _v421e
+	int _frameEdgeColor;	// _v421e
 	Rect _v5589E;
 	Rect _v558B6;
 	int _v558C2;
diff --git a/engines/tsage/ringworld2/ringworld2_scenes0.cpp b/engines/tsage/ringworld2/ringworld2_scenes0.cpp
index 3e55275..8696beb 100644
--- a/engines/tsage/ringworld2/ringworld2_scenes0.cpp
+++ b/engines/tsage/ringworld2/ringworld2_scenes0.cpp
@@ -1933,7 +1933,7 @@ void Scene180::restore() {
 		R2_GLOBALS._gfxColors.foreground = 4;
 		R2_GLOBALS._gfxColors.background = 3;
 		R2_GLOBALS._fontColors.background = 3;
-		R2_GLOBALS._frameEdgeColour = 3;
+		R2_GLOBALS._frameEdgeColor = 3;
 		break;
 
 	case 1:
@@ -1942,7 +1942,7 @@ void Scene180::restore() {
 		R2_GLOBALS._gfxColors.foreground = 25;
 		R2_GLOBALS._gfxColors.background = 43;
 		R2_GLOBALS._fontColors.background = 48;
-		R2_GLOBALS._frameEdgeColour = 48;
+		R2_GLOBALS._frameEdgeColor = 48;
 		break;
 
 	case 2:
@@ -1952,7 +1952,7 @@ void Scene180::restore() {
 		R2_GLOBALS._gfxColors.background = 136;
 		R2_GLOBALS._fontColors.background = 48;
 		R2_GLOBALS._fontColors.foreground = 253;
-		R2_GLOBALS._frameEdgeColour = 48;
+		R2_GLOBALS._frameEdgeColor = 48;
 		break;
 
 	case 3:
@@ -1961,7 +1961,7 @@ void Scene180::restore() {
 		R2_GLOBALS._gfxColors.foreground = 84;
 		R2_GLOBALS._gfxColors.background = 118;
 		R2_GLOBALS._fontColors.background = 47;
-		R2_GLOBALS._frameEdgeColour = 48;
+		R2_GLOBALS._frameEdgeColor = 48;
 		break;
 
 	case 14:
@@ -1971,7 +1971,7 @@ void Scene180::restore() {
 		R2_GLOBALS._fontColors.foreground = 38;
 		R2_GLOBALS._gfxColors.foreground = 192;
 		R2_GLOBALS._gfxColors.background = 30;
-		R2_GLOBALS._frameEdgeColour = 48;
+		R2_GLOBALS._frameEdgeColor = 48;
 		break;
 
 	default:
@@ -5754,7 +5754,7 @@ void Scene600::postInit(SceneObjectList *OwnerList) {
 	R2_GLOBALS._walkRegions.enableRegion(3);
 	_field412 = 0;
 
-	// Initialise pixel map for the obscuring effect
+	// Initialize pixel map for the obscuring effect
 	ScenePalette &pal = R2_GLOBALS._scenePalette;
 	uint r, g, b;
 	for (int i = 0; i < 256; ++i) {
diff --git a/engines/tsage/ringworld2/ringworld2_scenes1.cpp b/engines/tsage/ringworld2/ringworld2_scenes1.cpp
index 8d65c11..5666bc6 100644
--- a/engines/tsage/ringworld2/ringworld2_scenes1.cpp
+++ b/engines/tsage/ringworld2/ringworld2_scenes1.cpp
@@ -8238,7 +8238,7 @@ void Scene1550::dispatch() {
 
 	if ((R2_GLOBALS._v565EC[R2_GLOBALS._player._characterIndex] == 15) && (R2_GLOBALS._v565EC[R2_GLOBALS._player._characterIndex + 2] == 16)) {
 		R2_GLOBALS._player._shade = 0;
-		// Original game contains a switch based on an uninitialised variable.
+		// Original game contains a switch based on an uninitialized variable.
 		// Until we understand what should really happen there, this code is unused on purpose
 		int missingVariable = 0;
 		switch (missingVariable) {
diff --git a/engines/tsage/ringworld2/ringworld2_speakers.cpp b/engines/tsage/ringworld2/ringworld2_speakers.cpp
index a0b0bd4..cc60f97 100644
--- a/engines/tsage/ringworld2/ringworld2_speakers.cpp
+++ b/engines/tsage/ringworld2/ringworld2_speakers.cpp
@@ -2573,9 +2573,9 @@ void SpeakerSocko3200::proc15() {
 // Classes related to SOLDIER
 //----------------------------------------------------------------------------
 
-SpeakerSoldier::SpeakerSoldier(int colour) {
+SpeakerSoldier::SpeakerSoldier(int color) {
 	_speakerName = "SOLDIER";
-	_color1 = colour;
+	_color1 = color;
 	_color2 = 0;
 	_speakerMode = 0;
 	_textWidth = 300;
@@ -2869,9 +2869,9 @@ void SpeakerTomko3245::proc15() {
 // Classes related to WEBBSTER
 //----------------------------------------------------------------------------
 
-SpeakerWebbster::SpeakerWebbster(int colour) {
+SpeakerWebbster::SpeakerWebbster(int color) {
 	_speakerName = "WEBBSTER";
-	_color1 = colour;
+	_color1 = color;
 	_color2 = 0;
 	_speakerMode = 0;
 	_textWidth = 300;
diff --git a/engines/tsage/ringworld2/ringworld2_speakers.h b/engines/tsage/ringworld2/ringworld2_speakers.h
index 73e6dcf..e0618fb 100644
--- a/engines/tsage/ringworld2/ringworld2_speakers.h
+++ b/engines/tsage/ringworld2/ringworld2_speakers.h
@@ -506,7 +506,7 @@ public:
 
 class SpeakerSoldier : public VisualSpeaker {
 public:
-	SpeakerSoldier(int colour);
+	SpeakerSoldier(int color);
 	virtual Common::String getClassName() { return "SpeakerSoldier"; }
 };
 
@@ -581,7 +581,7 @@ public:
 
 class SpeakerWebbster : public VisualSpeaker {
 public:
-	SpeakerWebbster(int colour);
+	SpeakerWebbster(int color);
 	virtual Common::String getClassName() { return "SpeakerWebbster"; }
 };
 






More information about the Scummvm-git-logs mailing list
diff --git a/engines/tsage/graphics.cpp b/engines/tsage/graphics.cpp
index 1815c3d..2395cc6 100644
--- a/engines/tsage/graphics.cpp
+++ b/engines/tsage/graphics.cpp
@@ -806,20 +806,20 @@ void GfxElement::drawFrame() {
 		*((byte *)surface.getBasePtr(tempRect.right - 1, tempRect.bottom - 1)) = 0;
 
 		// Inner frame border
-		surface.hLine(tempRect.left + 2, tempRect.top + 1, tempRect.right - 2, R2_GLOBALS._frameEdgeColour); 
-		surface.hLine(tempRect.left + 2, tempRect.bottom - 1, tempRect.right - 2, R2_GLOBALS._frameEdgeColour); 
-		surface.vLine(tempRect.left + 1, tempRect.top + 2, tempRect.bottom - 2, R2_GLOBALS._frameEdgeColour);
-		surface.vLine(tempRect.right - 1, tempRect.top + 2, tempRect.bottom - 2, R2_GLOBALS._frameEdgeColour);
-		*((byte *)surface.getBasePtr(tempRect.left + 2, tempRect.top + 2)) = R2_GLOBALS._frameEdgeColour;
-		*((byte *)surface.getBasePtr(tempRect.right - 2, tempRect.top + 2)) = R2_GLOBALS._frameEdgeColour;
-		*((byte *)surface.getBasePtr(tempRect.left + 2, tempRect.bottom - 2)) = R2_GLOBALS._frameEdgeColour;
-		*((byte *)surface.getBasePtr(tempRect.right - 2, tempRect.bottom - 2)) = R2_GLOBALS._frameEdgeColour;
+		surface.hLine(tempRect.left + 2, tempRect.top + 1, tempRect.right - 2, R2_GLOBALS._frameEdgeColor); 
+		surface.hLine(tempRect.left + 2, tempRect.bottom - 1, tempRect.right - 2, R2_GLOBALS._frameEdgeColor); 
+		surface.vLine(tempRect.left + 1, tempRect.top + 2, tempRect.bottom - 2, R2_GLOBALS._frameEdgeColor);
+		surface.vLine(tempRect.right - 1, tempRect.top + 2, tempRect.bottom - 2, R2_GLOBALS._frameEdgeColor);
+		*((byte *)surface.getBasePtr(tempRect.left + 2, tempRect.top + 2)) = R2_GLOBALS._frameEdgeColor;
+		*((byte *)surface.getBasePtr(tempRect.right - 2, tempRect.top + 2)) = R2_GLOBALS._frameEdgeColor;
+		*((byte *)surface.getBasePtr(tempRect.left + 2, tempRect.bottom - 2)) = R2_GLOBALS._frameEdgeColor;
+		*((byte *)surface.getBasePtr(tempRect.right - 2, tempRect.bottom - 2)) = R2_GLOBALS._frameEdgeColor;
 
 		gfxManager.unlockSurface();
 		gfxManager.getSurface().addDirtyRect(tempRect);
 
 	} else {
 		// Fill dialog content with specified background colour
 		gfxManager.fillRect(tempRect, _colors.background);
 
 		--tempRect.bottom; --tempRect.right;
@@ -806,20 +806,20 @@ void GfxElement::drawFrame() {
 
 	} else {
-		// Fill dialog content with specified background colour
+		// Fill dialog content with specified background color
 		gfxManager.fillRect(tempRect, _colors.background);
 
diff --git a/engines/tsage/ringworld2/ringworld2_logic.cpp b/engines/tsage/ringworld2/ringworld2_logic.cpp
index 7104e1f..1264232 100644
--- a/engines/tsage/ringworld2/ringworld2_logic.cpp
+++ b/engines/tsage/ringworld2/ringworld2_logic.cpp
@@ -337,7 +337,7 @@ void SceneExt::postInit(SceneObjectList *OwnerList) {
 	// Exclude the bottom area of the screen to allow room for the UI
 	T2_GLOBALS._interfaceY = UI_INTERFACE_Y;
 
-	// Initialise fields
+	// Initialize fields
 	_action = NULL;
 	_field12 = 0;
 	_sceneMode = 0;
@@ -621,7 +621,7 @@ void SceneHandlerExt::postLoad(int priorSceneBeforeLoad, int currentSceneBeforeL
 		R2_GLOBALS._gfxColors.foreground = 59;
 		R2_GLOBALS._fontColors.background = 4;
 		R2_GLOBALS._fontColors.foreground = 15;
-		R2_GLOBALS._frameEdgeColour = 2;
+		R2_GLOBALS._frameEdgeColor = 2;
 
 		R2_GLOBALS._scenePalette.loadPalette(0);
 		R2_GLOBALS._scenePalette.setEntry(255, 0xff, 0xff, 0xff);
@@ -665,7 +665,7 @@ void SceneHandlerExt::setupPaletteMaps() {
 					break;
 				}
 
 				// Scan for the palette index with the closest matching colour
 				int threshold = 769;
 				int foundIndex = -1;
 				for (int pIndex2 = 223; pIndex2 >= 0; --pIndex2) {
@@ -1886,7 +1886,7 @@ bool AnimationPlayer::load(int animId, Action *endAction) {
 
 	default:
 		// ANIMPALMODE_CURR_PALETTE
-		// Use the closest matching colours in the currently active palette to those specified in the animation
+		// Use the closest matching colors in the currently active palette to those specified in the animation
 		for (int idx = _subData._palStart; idx < (_subData._palStart + _subData._palSize); ++idx) {
 			byte r = _subData._palData[idx * 3];
 			byte g = _subData._palData[idx * 3 + 1];
@@ -665,7 +665,7 @@ void SceneHandlerExt::setupPaletteMaps() {
 				}
 
-				// Scan for the palette index with the closest matching colour
+				// Scan for the palette index with the closest matching color
 				int threshold = 769;
 				int foundIndex = -1;